@@ -31,6 +31,36 @@ function checkAddUser(the_form)
     return PMA_checkPassword($(the_form));
 } // end of the 'checkAddUser()' function
 
+function checkPasswordStrength(value, meter_obj, meter_object_label, username) {
+    // List of words we don't want to appear in the password
+    customDict = [
+        'phpmyadmin',
+        'mariadb',
+        'mysql',
+        'php',
+        'my',
+        'admin',
+    ];
+    if (username != null) {
+        customDict.push(username)
+    }
+    var zxcvbn_obj = zxcvbn(value, customDict);
+    var strength = zxcvbn_obj.score;
+    strength = parseInt(strength);
+    meter_obj.val(strength);
+    switch(strength){
+        case 0: meter_obj_label.html(PMA_messages.strExtrWeak);
+                break;
+        case 1: meter_obj_label.html(PMA_messages.strVeryWeak);
+                break;
+        case 2: meter_obj_label.html(PMA_messages.strWeak);
+                break;
+        case 3: meter_obj_label.html(PMA_messages.strGood);
+                break;
+        case 4: meter_obj_label.html(PMA_messages.strStrong);
+    }
+}
+
 /**
  * AJAX scripts for server_privileges page.
  *
@@ -92,6 +122,23 @@ AJAX.registerOnload('server_privileges.js', function () {
         }
     });
 
+    /**
+     * Indicating password strength
+     */
+    $('#text_pma_pw').on('keyup', function () {
+        meter_obj = $('#password_strength_meter');
+        meter_obj_label = $('#password_strength');
+        username = $('input[name="username"]');
+        username = username.val();
+        checkPasswordStrength($(this).val(), meter_obj, meter_obj_label, username);
+    });
+
+    $('#text_pma_change_pw').on('keyup', function () {
+        meter_obj = $('#change_password_strength_meter');
+        meter_obj_label = $('#change_password_strength');
+        checkPasswordStrength($(this).val(), meter_obj, meter_obj_label, PMA_commonParams.get('user'));
+    });
+
     /**
      * Display a notice if sha256_password is selected
      */
@@ -189,7 +236,7 @@ AJAX.registerOnload('server_privileges.js', function () {
                             .find('select[name="userGroup"]')
                             .val();
                         var $message = PMA_ajaxShowMessage();
-                        $.get(
+                        $.post(
                             'server_privileges.php',
                             $('#changeUserGroupDialog').find('form').serialize() + '&ajax_request=1',
                             function (data) {
@@ -345,7 +392,7 @@ AJAX.registerOnload('server_privileges.js', function () {
 
     $(document).on('change', 'input[name="ssl_type"]', function (e) {
         var $div = $('#specified_div');
-        if ($('#ssl_type_specified').is(':checked')) {
+        if ($('#ssl_type_SPECIFIED').is(':checked')) {
             $div.find('input').prop('disabled', false);
         } else {
             $div.find('input').prop('disabled', true);
@@ -356,7 +403,7 @@ AJAX.registerOnload('server_privileges.js', function () {
         var $div = $('#require_ssl_div');
         if ($(this).is(':checked')) {
             $div.find('input').prop('disabled', false);
-            $('#ssl_type_specified').trigger('change');
+            $('#ssl_type_SPECIFIED').trigger('change');
         } else {
             $div.find('input').prop('disabled', true);
         }
