@@ -8,6 +8,7 @@
 namespace PMA\libraries;
 
 use PMA\libraries\URL;
+use PMA\libraries\Util;
 
 /**
  * Class to handle database QBE search
@@ -1561,7 +1562,7 @@ class DbQbe
         if (empty($from_clause)) {
             // Create cartesian product
             $from_clause = implode(
-                ", ", array_map('PMA\libraries\Util::backquote', $search_tables)
+                ", ", array_map(array('Util', 'backquote'), $search_tables)
             );
         }
 
@@ -1667,7 +1668,7 @@ class DbQbe
             if (count($unfinalized) > 0) {
                 // Add these tables as cartesian product before joined tables
                 $join .= implode(
-                    ', ', array_map('Util::backquote', $unfinalized)
+                    ', ', array_map(array('Util', 'backquote'), $unfinalized)
                 );
             }
         }
