@@ -15,13 +15,13 @@ use PMA\libraries\Message;
 use PMA\libraries\Template;
 use PMA\libraries\Util;
 use PMA\Util as Util_lib;
-use SqlParser;
-use SqlParser\Statements\CreateStatement;
-use SqlParser\Utils\Table as SqlTable;
+use PhpMyAdmin\SqlParser;
+use PhpMyAdmin\SqlParser\Statements\CreateStatement;
+use PhpMyAdmin\SqlParser\Utils\Table as SqlTable;
 use PMA\libraries\Table;
 use PMA\libraries\controllers\TableController;
+use PMA\libraries\URL;
 
-require_once 'libraries/mysql_charsets.inc.php';
 require_once 'libraries/transformations.lib.php';
 require_once 'libraries/util.lib.php';
 require_once 'libraries/config/messages.inc.php';
@@ -119,7 +119,6 @@ class TableStructureController extends TableController
         include_once 'libraries/check_user_privileges.lib.php';
         include_once 'libraries/index.lib.php';
         include_once 'libraries/sql.lib.php';
-        include_once 'libraries/bookmark.lib.php';
 
         $this->response->getHeader()->getScripts()->addFiles(
             array(
@@ -147,11 +146,11 @@ class TableStructureController extends TableController
                 $columns_names = $_REQUEST['field_name'];
                 $reserved_keywords_names = array();
                 foreach ($columns_names as $column) {
-                    if (SqlParser\Context::isKeyword(trim($column), true)) {
+                    if (\PhpMyAdmin\SqlParser\Context::isKeyword(trim($column), true)) {
                         $reserved_keywords_names[] = trim($column);
                     }
                 }
-                if (SqlParser\Context::isKeyword(trim($this->table), true)) {
+                if (\PhpMyAdmin\SqlParser\Context::isKeyword(trim($this->table), true)) {
                     $reserved_keywords_names[] = trim($this->table);
                 }
                 if (count($reserved_keywords_names) == 0) {
@@ -550,9 +549,9 @@ class TableStructureController extends TableController
             return null;
         }
 
-        $parser = new SqlParser\Parser($createTable);
+        $parser = new \PhpMyAdmin\SqlParser\Parser($createTable);
         /**
-         * @var $stmt SqlParser\Statements\CreateStatement
+         * @var $stmt PhpMyAdmin\SqlParser\Statements\CreateStatement
          */
         $stmt = $parser->statements[0];
 
@@ -602,12 +601,16 @@ class TableStructureController extends TableController
         $partitionDetails['can_have_subpartitions']
             = $partitionDetails['partition_count'] > 1
                 && ($partitionDetails['partition_by'] == 'RANGE'
-                || $partitionDetails['partition_by'] == 'LIST');
+                || $partitionDetails['partition_by'] == 'RANGE COLUMNS'
+                || $partitionDetails['partition_by'] == 'LIST'
+                || $partitionDetails['partition_by'] == 'LIST COLUMNS');
 
         // Values are specified only for LIST and RANGE type partitions
         $partitionDetails['value_enabled'] = isset($partitionDetails['partition_by'])
             && ($partitionDetails['partition_by'] == 'RANGE'
-            || $partitionDetails['partition_by'] == 'LIST');
+            || $partitionDetails['partition_by'] == 'RANGE COLUMNS'
+            || $partitionDetails['partition_by'] == 'LIST'
+            || $partitionDetails['partition_by'] == 'LIST COLUMNS');
 
         $partitionDetails['partitions'] = array();
 
@@ -615,6 +618,7 @@ class TableStructureController extends TableController
 
             if (! isset($stmt->partitions[$i])) {
                 $partitionDetails['partitions'][$i] = array(
+                    'name' => 'p' . $i,
                     'value_type' => '',
                     'value' => '',
                     'engine' => '',
@@ -635,6 +639,7 @@ class TableStructureController extends TableController
                     $expr = '';
                 }
                 $partitionDetails['partitions'][$i] = array(
+                    'name' => $p->name,
                     'value_type' => $type,
                     'value' => $expr,
                     'engine' => $p->options->has('ENGINE', true),
@@ -649,7 +654,6 @@ class TableStructureController extends TableController
             }
 
             $partition =& $partitionDetails['partitions'][$i];
-            $partition['name'] = 'p' . $i;
             $partition['prefix'] = 'partitions[' . $i . ']';
 
             if ($partitionDetails['subpartition_count'] > 1) {
@@ -659,6 +663,7 @@ class TableStructureController extends TableController
                 for ($j = 0; $j < intval($partitionDetails['subpartition_count']); $j++) {
                     if (! isset($stmt->partitions[$i]->subpartitions[$j])) {
                         $partition['subpartitions'][$j] = array(
+                            'name' => $partition['name'] . '_s' . $j,
                             'engine' => '',
                             'comment' => '',
                             'data_directory' => '',
@@ -671,6 +676,7 @@ class TableStructureController extends TableController
                     } else {
                         $sp = $stmt->partitions[$i]->subpartitions[$j];
                         $partition['subpartitions'][$j] = array(
+                            'name' => $sp->name,
                             'engine' => $sp->options->has('ENGINE', true),
                             'comment' => trim($sp->options->has('COMMENT', true), "'"),
                             'data_directory' => trim($sp->options->has('DATA DIRECTORY', true), "'"),
@@ -683,7 +689,6 @@ class TableStructureController extends TableController
                     }
 
                     $subpartition =& $partition['subpartitions'][$j];
-                    $subpartition['name'] = 'p' . $i . 's' . $j;
                     $subpartition['prefix'] = 'partitions[' . $i . ']'
                         . '[subpartitions][' . $j . ']';
                 }
@@ -826,7 +831,7 @@ class TableStructureController extends TableController
      */
     protected function updateColumns()
     {
-        $err_url = 'tbl_structure.php' . PMA_URL_getCommon(
+        $err_url = 'tbl_structure.php' . URL::getCommon(
             array(
                 'db' => $this->db, 'table' => $this->table
             )
@@ -1034,9 +1039,7 @@ class TableStructureController extends TableController
         ) {
             foreach ($_REQUEST['field_mimetype'] as $fieldindex => $mimetype) {
                 if (isset($_REQUEST['field_name'][$fieldindex])
-                    && mb_strlen(
-                        $_REQUEST['field_name'][$fieldindex]
-                    )
+                    && strlen($_REQUEST['field_name'][$fieldindex]) > 0
                 ) {
                     PMA_setMIME(
                         $this->db, $this->table,
@@ -1205,8 +1208,8 @@ class TableStructureController extends TableController
                     FROM `INFORMATION_SCHEMA`.`VIEWS`
                     WHERE TABLE_SCHEMA='%s'
                     AND TABLE_NAME='%s';",
-                    Util::sqlAddSlashes($this->db),
-                    Util::sqlAddSlashes($this->table)
+                    $GLOBALS['dbi']->escapeString($this->db),
+                    $GLOBALS['dbi']->escapeString($this->table)
                 )
             );
 
@@ -1228,7 +1231,7 @@ class TableStructureController extends TableController
             );
 
             $edit_view_url = 'view_create.php'
-                . PMA_URL_getCommon($url_params) . '&amp;'
+                . URL::getCommon($url_params) . '&amp;'
                 . implode(
                     '&amp;',
                     array_map(
