@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\URL;
+
 if (! defined('PHPMYADMIN')) {
     exit;
 }
@@ -22,7 +24,7 @@ if (empty($viewing_mode)) {
 /**
  * Set parameters for links
  */
-$GLOBALS['url_query'] = PMA_URL_getCommon(array('db' => $db));
+$GLOBALS['url_query'] = URL::getCommon(array('db' => $db));
 
 /**
  * Defines the urls to return to in case of error in a sql statement
