@@ -6,6 +6,9 @@
  * @package PhpMyAdmin
  */
 use PMA\libraries\Linter;
+use PMA\libraries\Response;
+
+$_GET['ajax_request'] = 'true';
 
 /**
  * Loading common files. Used to check for authorization, localization and to
@@ -27,7 +30,7 @@ require_once 'libraries/common.inc.php';
 $sql_query = !empty($_POST['sql_query']) ? $_POST['sql_query'] : '';
 
 // Disabling standard response.
-PMA\libraries\Response::getInstance()->disable();
+Response::getInstance()->disable();
 
 PMA_headerJSON();
 
@@ -37,7 +40,8 @@ if (! empty($_POST['options'])) {
     if (! empty($options['routine_editor'])) {
         $sql_query = 'CREATE PROCEDURE `a`() ' . $sql_query;
     } elseif (! empty($options['trigger_editor'])) {
-        $sql_query = 'CREATE TRIGGER `a` AFTER INSERT ON `b` FOR EACH ROW ' . $sql_query;
+        $sql_query = 'CREATE TRIGGER `a` AFTER INSERT ON `b` FOR EACH ROW '
+            . $sql_query;
     } elseif (! empty($options['event_editor'])) {
         $sql_query = 'CREATE EVENT `a` ON SCHEDULE EVERY MINUTE DO ' . $sql_query;
     }
